```
Usage: vcd vapp undeploy [OPTIONS] NAME [VM_NAMES]...

Options:
  -y, --yes
  --action [default|powerOff|suspend|shutdown|force]
                                  Undeploy power action
  -h, --help                      Show this message and exit.

```
